@@ -3,7 +3,7 @@ from pkg_resources import get_distribution
 from typing import Dict, Type, TypeVar, List, Optional
 from requests import get
 from tdw.output_data import OutputData, Transforms, Rigidbodies, Bounds, Images, SegmentationColors, Volumes, Raycast, \
-    CompositeObjects, CameraMatrices, SceneRegions, Overlap, Version, StaticRobot, Robot, Magnebot, NavMeshPath, \
+    CameraMatrices, SceneRegions, Overlap, Version, StaticRobot, Robot, Magnebot, NavMeshPath, \
     ScreenPosition, AudioSources, AvatarKinematic, ImageSensors
 
 
@@ -16,7 +16,6 @@ __OUTPUT_IDS: Dict[Type[OutputData], str] = {Transforms: "tran",
                                              SegmentationColors: "segm",
                                              Volumes: "volu",
                                              Raycast: "rayc",
-                                             CompositeObjects: "comp",
                                              CameraMatrices: "cama",
                                              SceneRegions: "sreg",
                                              Overlap: "over",
